executions

package
v0.0.11 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 2, 2025 License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Overview

Copyright Project Harbor Authors

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ListCommand

func ListCommand() *cobra.Command

func ViewCommand

func ViewCommand() *cobra.Command

Types

type ExecutionsAndTasks

type ExecutionsAndTasks struct {
	Execution *models.ReplicationExecution      `json:"execution,omitempty" yaml:"execution,omitempty"`
	Tasks     map[int64]*models.ReplicationTask `json:"tasks,omitempty" yaml:"tasks,omitempty"`
}

func NewExecutionsAndTasks

func NewExecutionsAndTasks(execution *models.ReplicationExecution, tasks []*models.ReplicationTask) *ExecutionsAndTasks

Jump to