Documentation
¶
Overview ¶
Copyright Project Harbor Authors
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright Project Harbor Authors ¶
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright Project Harbor Authors ¶
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright Project Harbor Authors ¶
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Copyright Project Harbor Authors ¶
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Index ¶
- Variables
- func CreateLoginView(loginView *login.LoginView) error
- func HealthCommand() *cobra.Command
- func InfoCommand() *cobra.Command
- func LoadCredentialsIntoLoginView(credentialName string, config *utils.HarborConfig) (login.LoginView, error)
- func LoginCommand() *cobra.Command
- func ProcessLogin(loginView login.LoginView, config *utils.HarborConfig) error
- func RootCmd() *cobra.Command
- func RunLogin(opts login.LoginView) error
Constants ¶
This section is empty.
Variables ¶
var ( Username string Password string Name string )
Functions ¶
func CreateLoginView ¶ added in v0.0.4
CreateLoginView launches the interactive login view. In this implementation, it calls login.CreateView and then tries to run login.
func HealthCommand ¶ added in v0.0.2
func InfoCommand ¶ added in v0.0.4
func LoadCredentialsIntoLoginView ¶ added in v0.0.4
func LoadCredentialsIntoLoginView(credentialName string, config *utils.HarborConfig) (login.LoginView, error)
LoadCredentialsIntoLoginView loads a stored credential from the config by name and returns a LoginView.
func LoginCommand ¶
LoginCommand creates a new `harbor login` command
func ProcessLogin ¶ added in v0.0.4
func ProcessLogin(loginView login.LoginView, config *utils.HarborConfig) error
ProcessLogin applies a simplified decision logic to run login or launch an interactive view.
Types ¶
This section is empty.